import 'dart:convert';

import 'package:flutter/services.dart';

abstract class AppConfigure {
  static Map<String, dynamic> _config = {};

  static Future<void> initialize(String env) async {
    final configString = await rootBundle.loadString('config/app_config_$env.json');
    _config = json.decode(configString) as Map<String, dynamic>;
  }

  static String getEndpoint() {
    return _config['endpoint'] as String;
  }

  static AppConfigureEnv getAppConfigureEnv() {
    switch (_config['env']) {
      case 'dev':
        return AppConfigureEnv.dev;
      case 'staging':
        return AppConfigureEnv.staging;
      case 'prod':
        return AppConfigureEnv.prod;
    }
    throw Exception('Unknown enviroment');
  }
}

enum AppConfigureEnv { dev, prod, staging }
