import 'package:award_app_api_service_flutter/network/uris/endpoints.dart';
import 'package:package_info_plus/package_info_plus.dart';

import '../constant.dart';
import 'dio_client.dart';
import 'models/token_model.dart';
import 'models/token_request_model.dart';

enum ServiceType {
  issueCoupon,
  useCoupon,
  loginByQRCode,
  coinSubtraction,
  coinAddition,
  shopCheckin,
}

extension ServiceTypeStringValue on ServiceType {
  String stringValue() {
    switch (this) {
      case ServiceType.issueCoupon:
        return "000000001";
      case ServiceType.useCoupon:
        return "000000002";
      case ServiceType.loginByQRCode:
        return "000000003";
      case ServiceType.coinSubtraction:
        return "000000004";
      case ServiceType.coinAddition:
        return "000000005";
      case ServiceType.shopCheckin:
        return "000000009";
    }
  }
}

class APIService {
  static final APIService _instance = APIService._();

  APIService._();

  static APIService get instance => _instance;

  // MARK: - Variables
  final DioClient _dioClient = DioClient();

  Future<TokenRequestModel> get _tokenRequest async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();

    String scope = "coupon account qrcode";
    if (packageInfo.appName == TargetKey.coin.appName) {
      scope = "coin";
    } else if (packageInfo.appName == TargetKey.pocker.appName) {
      scope = "account";
    }
    return TokenRequestModel(
      clientId: "client",
      clientSecret: "secret",
      scope: scope,
      grantType: "client_credentials",
    );
  }

  // MARK: - Functions

  Future<TokenModel?> callApiGetToken() async {
    final tokenRequest = await _tokenRequest;
    final dynamic response = await _dioClient.post(
      Endpoints.getToken,
      queryParameters: tokenRequest.toJson(),
    );

    final tokenModel = TokenModel.fromJson(response);

    return tokenModel;
  }
}
